@@ -15,7 +15,8 @@ from time import sleep
 from selenium.webdriver import Remote, ActionChains
 from selenium.webdriver.chrome import options
 from selenium.common.exceptions import InvalidArgumentException
-
+import getpass
+import subprocess
 
 def chrome_open_mobile(chrome_options=[], userdata_path=r"c:\chrome_mobile"):
     options = webdriver.ChromeOptions()
@@ -201,13 +202,68 @@ def wait_disappear_element(driver, locator, wait_time=10):
     WebDriverWait(driver, wait_time).until_not(EC.visibility_of_element_located((locator_strategy, locator)))
 
 
-def recontrol_opened_chrome():
-    os.system(r'"C:/"Program Files (x86)/Google/Chrome/Application/chrome.exe" --remote-debugging-port=9222 --user-data-dir="C:/chrome_userdata"')
 
-    chrome_options = webdriver.ChromeOptions()
-    chrome_options.add_experimental_option("debuggerAddress", "127.0.0.1:9222")
-    driver = webdriver.Chrome(chrome_options=chrome_options)
-    driver.get('https://cn.bing.com')
+
+
+def reconnect_chrome():
+    options = webdriver.ChromeOptions()
+    options.add_experimental_option("debuggerAddress", "127.0.0.1:9222")
+
+    options.add_argument('--no-sandbox')
+    options.add_argument('--disable-dev-shm-usage')
+
+    # options.add_argument('--incognito')  #  隐身模式
+    # options.add_argument('--headless')
+
+    options.add_argument("--disable-extensions")
+    options.add_argument("--allow-running-insecure-content")
+    options.add_argument('--disable-infobars')  # 关闭浏览器上方自动测试提示
+    options.add_argument('--start-maximized')  # –start-maximized 启动就最大化
+    # options.add_argument('--no-startup-window')  # 关闭启动弹窗 可能导致chrome无法启动，注释不再用
+    options.add_argument('--disable-blink-features=AutomationControlled') # Modifying navigator.webdriver flag to prevent selenium detection
+    options.add_argument(rf'--user-data-dir="C:/Users/{getpass.getuser()}/AppData/Local/Google/Chrome/User Data"')
+
+
+
+
+    # options.add_experimental_option('useAutomationExtension', False)
+    # options.add_experimental_option("detach", True) # 程序结束后chrome保持打开状态
+    # Modify chromedriver.exe $cdc to '$cdc_helloIamjameshowareyou_'
+    # options.add_experimental_option("excludeSwitches", ['enable-automation']) # Modifying navigator.webdriver flag to prevent selenium detection
+    #
+    # prefs = {"profile.managed_default_content_settings.images":0,
+    #          "profile.default_content_setting_values.notifications":2,
+    #          "profile.managed_default_content_settings.popups":2,
+    #          "profile.managed_default_content_settings.stylesheets":2,
+    #          "profile.managed_default_content_settings.cookies":1,
+    #          "profile.managed_default_content_settings.javascript":1,
+    #          "profile.managed_default_content_settings.plugins":1,
+    #          "profile.managed_default_content_settings.geolocation":2,
+    #          "profile.managed_default_content_settings.media_stream":2,
+    #          }# 0 ==> default, 1 ==> Allow, 2 ==> Block.
+    #
+    # options.add_experimental_option('prefs', prefs)
+
+    capa = DesiredCapabilities().CHROME
+    capa["pageLoadStrategy"] = "none"
+    # capa["os_version"] = "11"
+    # capa["device"] = "iPhone 8 Plus"
+    # capa["real_mobile"] = "true"
+    # capa["browserstack.local"] = "false"
+    try:
+        driver = webdriver.Chrome(options=options, desired_capabilities=capa)
+    except:
+        print("can't find a chrome open in port 9222, open it automaticly")
+
+        cmd = '''"C:\\Program Files (x86)\\Google\\Chrome\\Application\\chrome.exe" --remote-debugging-port=9222"'''
+        subprocess.Popen(cmd)
+
+        driver = webdriver.Chrome(options=options, desired_capabilities=capa)
+
+    driver.set_page_load_timeout(10) # 超时设置
+    driver.set_script_timeout(10)
+
+    return driver
 
 
 def configure_as_mobile(options, mobile_type='IPHONE_8'):
